==> camunda-engine-7.15.0-sources.jar: org/camunda/bpm/engine/impl/util/ProcessEngineDetails.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.util;

/**
 * Holds process engine version and edition (enterprise or community)
 * Used in retrieving the process engine details when sending telemetry data
 */
public class ProcessEngineDetails {

  public static final String EDITION_ENTERPRISE = "enterprise";
  public static final String EDITION_COMMUNITY = "community";

  protected String version;
  protected String edition;

  public ProcessEngineDetails(String version, String edition) {
    this.version = version;
    this.edition = edition;
  }

  public String getVersion() {
    return version;
  }

  public void setVersion(String version) {
    this.version = version;
  }

  public String getEdition() {
    return edition;
  }

  public void setEdition(String edition) {
    this.edition = edition;
  }

}

==> camunda-engine-7.22.0-sources.jar: org/camunda/bpm/engine/impl/util/ProcessEngineDetails.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH
 * under one or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information regarding copyright
 * ownership. Camunda licenses this file to you under the Apache License,
 * Version 2.0; you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.util;

/**
 * Holds process engine version and edition (enterprise or community)
 * Used in retrieving the process engine details for diagnostics data
 */
public class ProcessEngineDetails {

  public static final String EDITION_ENTERPRISE = "enterprise";
  public static final String EDITION_COMMUNITY = "community";

  protected String version;
  protected String edition;

  public ProcessEngineDetails(String version, String edition) {
    this.version = version;
    this.edition = edition;
  }

  public String getVersion() {
    return version;
  }

  public void setVersion(String version) {
    this.version = version;
  }

  public String getEdition() {
    return edition;
  }

  public void setEdition(String edition) {
    this.edition = edition;
  }

}
